#if $user is not None

User $user.get_full_name() ($user) on $site.title

#from lino.apps.dsbe.models import persons_by_user $persons_by_user($ui,$user) #from lino.modlib.cal.models import tasks_summary $tasks_summary($ui,$user,days_back=90,days_forward=30,max_items=10,before='

- ',separator='
- ',after="

") #else

user is None. Check your authentication configuration.

#end if

$lino.welcome_html()